@@ -10,20 +10,21 @@ use slack_morphism::signature_verifier::SlackEventSignatureVerifier;
 
 use futures::future::{BoxFuture, FutureExt, TryFutureExt};
 use hyper::body::*;
+use hyper::client::connect::Connect;
 use hyper::{Method, Request, Response, StatusCode};
 use slack_morphism::UserCallbackResult;
 use std::collections::HashMap;
 use std::future::Future;
 use std::sync::Arc;
 
-impl SlackClientEventsHyperListener {
+impl<H: 'static + Send + Sync + Connect + Clone> SlackClientEventsHyperListener<H> {
     pub fn interaction_events_service_fn<'a, D, F>(
         &self,
         config: Arc<SlackInteractionEventsListenerConfig>,
         interaction_service_fn: UserCallbackFunction<
             SlackInteractionEvent,
             impl Future<Output = UserCallbackResult<()>> + 'static + Send,
-            SlackClientHyperConnector,
+            SlackClientHyperConnector<H>,
         >,
     ) -> impl Fn(
         Request<Body>,
@@ -58,7 +59,7 @@ impl SlackClientEventsHyperListener {
             async move {
                 match (req.method(), req.uri().path()) {
                     (&Method::POST, url) if url == cfg.events_path => {
-                        SlackClientHyperConnector::decode_signed_response(req, &sign_verifier)
+                        SlackClientHyperConnector::<H>::decode_signed_response(req, &sign_verifier)
                             .map_ok(|body| {
                                 let body_params: HashMap<String, String> =
                                     url::form_urlencoded::parse(body.as_bytes())
